@@ -63,6 +63,14 @@ commands = {
         'func': littleangel,
         'convert': False
     },
+    'dont_touch': {
+        'aliases': {'不要靠近'},
+        'func': dont_touch
+    },
+    'alike': {
+        'aliases': {'一样'},
+        'func': alike
+    }
 }
 
 
