@@ -244,3 +244,15 @@ async def littleangel(img: IMG, name: str, **kwargs) -> Union[str, BytesIO]:
     y = 55 - text_h / 2
     draw.text((x, y), text, font=font, fill=(0, 0, 0))
     return save_jpg(bg)
+
+
+async def dont_touch(img: IMG, **kwargs) -> BytesIO:
+    frame = await load_image('dont_touch/0.png')
+    frame.paste(resize(img, (170, 170)), (23, 231))
+    return save_jpg(frame)
+
+
+async def alike(img: IMG, **kwargs) -> BytesIO:
+    frame = await load_image('alike/0.png')
+    frame.paste(resize(img, (90, 90)), (131, 14))
+    return save_jpg(frame)
